@@ -1658,6 +1658,8 @@ class CloudPickleTest(unittest.TestCase):
         pickle_depickle(DataClass, protocol=self.protocol)
         assert data.x == pickle_depickle(data, protocol=self.protocol).x == 42
 
+    @unittest.skipIf(sys.version_info[:2] < (3, 5),
+                     "Only support enum pickling on Python 3.5+")
     def test_locally_defined_enum(self):
         enum = pytest.importorskip("enum")
 
@@ -1689,6 +1691,8 @@ class CloudPickleTest(unittest.TestCase):
         green3 = pickle_depickle(Color.GREEN, protocol=self.protocol)
         assert green3 is Color.GREEN
 
+    @unittest.skipIf(sys.version_info[:2] < (3, 5),
+                     "Only support enum pickling on Python 3.5+")
     def test_locally_defined_intenum(self):
         enum = pytest.importorskip("enum")
         # Try again with a IntEnum defined with the functional API
@@ -1703,6 +1707,8 @@ class CloudPickleTest(unittest.TestCase):
         assert green1 is not ClonedDynamicColor.BLUE
         assert ClonedDynamicColor is DynamicColor
 
+    @unittest.skipIf(sys.version_info[:2] < (3, 5),
+                     "Only support enum pickling on Python 3.5+")
     def test_interactively_defined_enum(self):
         pytest.importorskip("enum")
         code = """if __name__ == "__main__":
